### CandleResult

| name | type | notes
| -- |-- |--
| `date` | datetime | Date
| `price` | decimal, Optional | Price of the most relevant OHLC candle element when a match is present
| `match` | [Match]({{site.baseurl}}/guide/#match) | Generated Match type
| `candle` | [CandleProperties]({{site.baseurl}}/guide/#candle) | Candle properties
